@extends('layouts.master')

@section('navigation')
    @if(Auth::user()->role==1)
        @include('local.managers.admins._navigation')
    @elseif(Auth::user()->role==2)
        @include('local.managers.sCoords._navigation')
    @elseif(Auth::user()->role==3)
        @include('local.managers.pCoords._navigation')
    @else
        @include('local.professors._navigation')
    @endif
@stop

@section('main')

    <div class="row">
        <div class="col-md-12">
            <p>{{$course->name}}</p>
        </div>
    </div>


    <div class="row">
        <div class="col-md-12">
            <h3>Activities</h3>

            @if(!$activities->isEmpty())

                @if ($is_active_semester)
                    <button data-toggle="modal" data-target="#newActivityModal" class="btn btn-sm btn-default pull-right"> New Activity</button>
                @endif

                <table class="table table-striped table-condensed">
                    <thead>
                    <tr>
                        <th>Name</th>
                        <th>Date</th>
                        <th>Updated</th>
                        <th>Assessed</th>
                        <th>Published</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach ($activities as $activity)
                        <tr>
                            <td>{{ link_to_action('ActivitiesController@show', $activity->name, $parameters = array('id'=>$activity->id)) }}</td>
                            <td>{{ date('M d, Y', strtotime($activity->date)) }}</td>
                            <td>{{ date('M d, Y', strtotime($activity->updated_at)) }}</td>
                            <td>
                                @if($activity->outcomes_attempted!=NULL)
                                    <span class="glyphicon glyphicon-ok"></span>
                                @endif
                            </td>
                            <td>
                                @if($activity->outcomes_attempted!=NULL && !$activity->draft)
                                    <span class="glyphicon glyphicon-ok"></span>
                                @endif
                            </td>
                        </tr>
                    @endforeach

                    @if (!$is_active_semester)
                        <tr>
                            <td colspan="3"><div class="alert alert-info">The semester for this course is inactive. You cannot create any more activities.</div></td>
                        </tr>
                    @endif
                    </tbody>
                </table>

                <p>Unplublished activity results are <strong>not considered</strong> in the graph above.</p>

            @else
                <div class="alert alert-info">
                    @if($is_active_semester)
                        <p>
                            No activities.
                            <a data-toggle="modal" data-target="#newActivityModal">
                                Create one.
                            </a>
                        </p>
                    @else
                        <p>The semester for this course is inactive. You cannot create any activities.</p>
                    @endif
                </div>
            @endif
        </div>
    </div>
@stop

@section('included-js')

    <!-- New Activity Modal -->
    <div class="modal fade" id="newActivityModal" tabindex="-1" role="dialog" aria-labelledby="newActivityModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-sm">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
                    <h4 class="modal-title" id="newActivityModalLabel">New Activity</h4>
                </div>
                <div class="modal-body">
                    {{ Form::open(array('action' => array('ActivitiesController@create', $course->id))) }}
                    <div class="form-group">
                        {{ Form::label('name', 'Name') }}
                        {{ Form::text('name', Input::old('name'), array('class' => 'form-control')) }}
                    </div>
                    <div class="form-group">
                        {{ Form::label('description', 'Description') }}
                        {{ Form::textarea('description', Input::old('description'), array('class' => 'form-control', 'rows'=> 5, 'placeholder'=>'Minimum 10 characters')) }}
                    </div>
                    <div class="btn-group" role="group">
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-default btn-primary">Submit</button>
                    </div>
                    {{ Form::close() }}
                </div>
            </div>
        </div>
    </div>
    <!-- HighCharts -->
    <script src="{{ asset('vendor/highcharts/highcharts.js') }}"></script>
    <!--script src="http://code.highcharts.com/modules/exporting.js"></script -->

@stop

@section('javascript')


@stop

